pub fn create_dir_all(
path: impl AsRef<Path>,
cap: &impl CapProvider<FsWrite>,
) -> Result<(), CapSecError>Expand description
Creates all directories in the given path if they don’t exist.
Requires FsWrite permission.
pub fn create_dir_all(
path: impl AsRef<Path>,
cap: &impl CapProvider<FsWrite>,
) -> Result<(), CapSecError>Creates all directories in the given path if they don’t exist.
Requires FsWrite permission.