pub fn read(
path: impl AsRef<Path>,
cap: &impl CapProvider<FsRead>,
) -> Result<Vec<u8>, CapSecError>Expand description
Reads the entire contents of a file into a byte vector.
Requires FsRead permission.
pub fn read(
path: impl AsRef<Path>,
cap: &impl CapProvider<FsRead>,
) -> Result<Vec<u8>, CapSecError>Reads the entire contents of a file into a byte vector.
Requires FsRead permission.