pub fn read_to_string(
path: impl AsRef<Path>,
cap: &impl CapProvider<FsRead>,
) -> Result<String, CapSecError>Expand description
Reads the entire contents of a file into a string.
Requires FsRead permission.
pub fn read_to_string(
path: impl AsRef<Path>,
cap: &impl CapProvider<FsRead>,
) -> Result<String, CapSecError>Reads the entire contents of a file into a string.
Requires FsRead permission.