pub fn run(
program: &str,
args: &[&str],
cap: &impl CapProvider<Spawn>,
) -> Result<Output, CapSecError>Expand description
Runs a program with arguments and returns its output.
Requires Spawn permission.
pub fn run(
program: &str,
args: &[&str],
cap: &impl CapProvider<Spawn>,
) -> Result<Output, CapSecError>Runs a program with arguments and returns its output.
Requires Spawn permission.